@@ -90,47 +90,3 @@ function FastShortcutNonlinearPolyalg(
     end
     return NonlinearSolvePolyAlgorithm(algs; start_index)
 end
-
-"""
-    FastShortcutNLLSPolyalg(
-        ::Type{T} = Float64;
-        concrete_jac = nothing,
-        linsolve = nothing,
-        autodiff = nothing, vjp_autodiff = nothing, jvp_autodiff = nothing
-    )
-
-A polyalgorithm focused on balancing speed and robustness. It first tries less robust methods
-for more performance and then tries more robust techniques if the faster ones fail.
-
-### Arguments
-
-  - `T`: The eltype of the initial guess. It is only used to check if some of the algorithms
-    are compatible with the problem type. Defaults to `Float64`.
-"""
-function FastShortcutNLLSPolyalg(
-        ::Type{T} = Float64;
-        concrete_jac = nothing,
-        linsolve = nothing,
-        autodiff = nothing, vjp_autodiff = nothing, jvp_autodiff = nothing
-    ) where {T}
-    common_kwargs = (; linsolve, autodiff, vjp_autodiff, jvp_autodiff)
-    if T <: Complex
-        algs = (
-            GaussNewton(; common_kwargs..., concrete_jac),
-            LevenbergMarquardt(; common_kwargs..., disable_geodesic = Val(true)),
-            LevenbergMarquardt(; common_kwargs...),
-        )
-    else
-        algs = (
-            GaussNewton(; common_kwargs..., concrete_jac),
-            LevenbergMarquardt(; common_kwargs..., disable_geodesic = Val(true)),
-            TrustRegion(; common_kwargs..., concrete_jac),
-            GaussNewton(; common_kwargs..., linesearch = BackTracking(), concrete_jac),
-            TrustRegion(;
-                common_kwargs..., radius_update_scheme = RUS.Bastin, concrete_jac
-            ),
-            LevenbergMarquardt(; common_kwargs...),
-        )
-    end
-    return NonlinearSolvePolyAlgorithm(algs)
-end
